//
//  ViewController.swift
//  CD5-Alerts
//
//  Created by bulko on 2/21/25.
//

import UIKit

class ViewController: UIViewController, UITableViewDelegate, UITableViewDataSource {

    @IBOutlet weak var tableView: UITableView!
    
    let textCellIdentifier = "TextCell"
    
    let choices = [
        "Simple UIAlertViewController",
        "UIAlertViewController with Multiple Buttons",
        "Standard UIActionSheet",
        "UIAlertViewController with TextField"
    ]
    
    override func viewDidLoad() {
        super.viewDidLoad()
        tableView.delegate = self
        tableView.dataSource = self
    }

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return choices.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: textCellIdentifier, for: indexPath)
        cell.textLabel?.text = choices[indexPath.row]
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        
        let rowValue = choices[indexPath.row]
        
        switch indexPath.row {
            
        case 0:  // Simple UIAlertViewController
        
            let controller = UIAlertController(
                title: "Alert Controller",
                message: rowValue,
                preferredStyle: .alert)
            
            controller.addAction(UIAlertAction(title: "Cancel", style: .cancel))
            controller.addAction(UIAlertAction(
                title: "OK",
                style: .default,
                handler: alertHandler(alert:)
            ))
            
            present(controller, animated: true)
            
        case 1:
            
            let controller = UIAlertController(
                title: "Alert Controller",
                message: rowValue,
                preferredStyle: .alert)
            
            controller.addAction(UIAlertAction(title: "One", style: .default))
            
            controller.addAction(UIAlertAction(
                title: "Two",
                style: .default,
                handler: { (alert) in print("Two clicked") } ))
            
            controller.addAction(UIAlertAction(
                title: "Three",
                style: .default) {
                    (alert) in print("Three clicked")
                }
            )
            
            controller.addAction(UIAlertAction(title: "Four", style: .default))
            controller.addAction(UIAlertAction(title: "Cancel", style: .cancel))
            
            present(controller, animated: true)
            
        case 2:  // Standard Action Sheet
            
            let controller = UIAlertController(
                title: "Alert Controller",
                message: rowValue,
                preferredStyle: .actionSheet)
            
            controller.addAction(UIAlertAction(title: "Cancel", style: .cancel)
                { (action) in print("Cancel action") } )
            controller.addAction(UIAlertAction(title: "OK", style: .default)
                { (action) in print("Accept data") } )
            controller.addAction(UIAlertAction(title: "Delete", style: .destructive)
                { (action) in print("Destroy data") } )
            
            present(controller, animated: true)
            
        case 3:   // UIAlertViewController with TextField
            
            let controller = UIAlertController(
                title: "Alert Controller",
                message: rowValue,
                preferredStyle: .alert)
            
            controller.addAction(UIAlertAction(title: "Cancel", style: .cancel))
            
            controller.addTextField(configurationHandler: {
                (textField) in
                textField.placeholder = "Enter something" } )
            
            controller.addAction(UIAlertAction(
                title: "OK",
                style: .default) {
                    (action) in
                    let enteredText = controller.textFields![0].text
                    print(enteredText!) } )
            
            present(controller, animated: true)
            
        default:
            makePopup(popupTitle: "Error:", popupMessage: "This shouldn't happen")
        }
        
    }
    
    func alertHandler(alert:UIAlertAction) {
        print("Message")
    }
    
    func makePopup(popupTitle:String, popupMessage:String) {
        
        let controller = UIAlertController(
            title: popupTitle,
            message: popupMessage,
            preferredStyle: .alert)
        
        controller.addAction(UIAlertAction(title: "OK", style: .default))
        
        present(controller,animated:true)
    }

}

